[−][src]Struct backtrace::BacktraceSymbol
Captured version of a symbol in a backtrace.
This type is returned as a list from BacktraceFrame::symbols and
represents the metadata for a symbol in a backtrace.
Required features
This function requires the std feature of the backtrace crate to be
enabled, and the std feature is enabled by default.
Implementations
impl BacktraceSymbol[src][−]
pub fn name(&self) -> Option<SymbolName<'_>>[src][−]
Same as Symbol::name
Required features
This function requires the std feature of the backtrace crate to be
enabled, and the std feature is enabled by default.
pub fn addr(&self) -> Option<*mut c_void>[src][−]
Same as Symbol::addr
Required features
This function requires the std feature of the backtrace crate to be
enabled, and the std feature is enabled by default.
pub fn filename(&self) -> Option<&Path>[src][−]
Same as Symbol::filename
Required features
This function requires the std feature of the backtrace crate to be
enabled, and the std feature is enabled by default.
pub fn lineno(&self) -> Option<u32>[src][−]
Same as Symbol::lineno
Required features
This function requires the std feature of the backtrace crate to be
enabled, and the std feature is enabled by default.